@@ -53,11 +53,13 @@ import java.util.HashMap;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
+import java.util.Map.Entry;
 import java.util.regex.Pattern;
 import java.util.regex.PatternSyntaxException;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
+import org.slf4j.Logger;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
@@ -77,6 +79,7 @@ import com.openexchange.config.cascade.ComposedConfigProperty;
 import com.openexchange.config.cascade.ConfigView;
 import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.exception.OXException;
+import com.openexchange.java.Strings;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 import com.openexchange.tools.session.ServerSession;
@@ -90,6 +93,8 @@ import com.openexchange.tools.session.ServerSession;
 @DispatcherNotes(noSession = true)
 public class ConfigAction implements AJAXActionService {
 
+    private static final Logger LOGGER = org.slf4j.LoggerFactory.getLogger(ConfigAction.class);
+
     private final ServiceLookup services;
     private final ServerConfigServicesLookup registry;
     private final ComputedServerConfigValueService[] computedValues;
@@ -99,8 +104,9 @@ public class ConfigAction implements AJAXActionService {
         this.services = services;
         this.registry = registry;
 
-        computedValues = new ComputedServerConfigValueService[]{
-            new Manifests(services, manifests), new Capabilities(services),
+        computedValues = new ComputedServerConfigValueService[] {
+            new Manifests(services, manifests),
+            new Capabilities(services),
             new Hosts(),
             new ServerVersion(),
             new Languages(services),
@@ -109,8 +115,7 @@ public class ConfigAction implements AJAXActionService {
     }
 
     @Override
-    public AJAXRequestResult perform(AJAXRequestData requestData,
-        ServerSession session) throws OXException {
+    public AJAXRequestResult perform(AJAXRequestData requestData, ServerSession session) throws OXException {
         try {
             JSONObject serverconfig = getFromConfiguration(requestData, session);
 
@@ -119,7 +124,7 @@ public class ConfigAction implements AJAXActionService {
 
             return new AJAXRequestResult(serverconfig, "json");
         } catch (JSONException x) {
-            throw AjaxExceptionCodes.JSON_ERROR.create(x.toString());
+            throw AjaxExceptionCodes.JSON_ERROR.create(x, x.toString());
         }
     }
 
@@ -140,69 +145,107 @@ public class ConfigAction implements AJAXActionService {
     @SuppressWarnings("unchecked")
     protected JSONObject getFromConfiguration(AJAXRequestData requestData, ServerSession session) throws JSONException, OXException {
         // Get configured brands/server configurations
-        Map<String, Object> serverConfigs = (Map<String, Object>) services.getService(ConfigurationService.class).getYaml("as-config.yml");
+        Map<String, Object> configurations = (Map<String, Object>) services.getService(ConfigurationService.class).getYaml("as-config.yml");
+        debugOut("as-config.yml", configurations);
 
         // The resulting brand/server configuration
-        Map<String, Object> serverConfig = new HashMap<String, Object>();
+        Map<String, Object> serverConfiguration = new HashMap<String, Object>(4);
 
         // Check for default brands/server configurations
         {
             Map<String, Object> defaults = (Map<String, Object>) services.getService(ConfigurationService.class).getYaml("as-config-defaults.yml");
             if (defaults != null) {
-                serverConfig.putAll((Map<String, Object>) defaults.get("default"));
+                serverConfiguration.putAll((Map<String, Object>) defaults.get("default"));
+                debugOut("as-config-defaults.yml", defaults);
             }
         }
 
-        // Find other applicable configurations
-        if (serverConfigs != null) {
+        // Find other applicable brands/server configurations
+        if (configurations != null) {
+            boolean empty = true;
             LinkedList<Map<String, Object>> applicableConfigs = new LinkedList<Map<String,Object>>();
-            for (Object value : serverConfigs.values()) {
-                Map<String, Object> possibleConfig = (Map<String, Object>) value;
-                if (looksApplicable(possibleConfig, requestData, session)) {
+            for (Map.Entry<String, Object> configEntry : configurations.entrySet()) {
+                Map<String, Object> possibleConfiguration = (Map<String, Object>) configEntry.getValue();
+                if (looksApplicable(possibleConfiguration, requestData, session)) {
                     // ensure that "all"-host-wildcards are applied first
-                    if ("all".equals(possibleConfig.get("host"))) {
-                        applicableConfigs.addFirst(possibleConfig);
+                    if ("all".equals(possibleConfiguration.get("host"))) {
+                        applicableConfigs.addFirst(possibleConfiguration);
                     } else {
-                        applicableConfigs.add(possibleConfig);
+                        applicableConfigs.add(possibleConfiguration);
+                    }
+                    empty = false;
+                } else {
+                    final String configName = configEntry.getKey();
+                    if (null == possibleConfiguration) {
+                        LOGGER.debug("Empty configuration \"{}\" is not applicable", configName);
+                    } else {
+                        LOGGER.debug("Configuration \"{}\" is not applicable: {}", configName, prettyPrint(configName, possibleConfiguration));
                     }
                 }
             }
-            for (Map<String, Object> config : applicableConfigs) {
-                serverConfig.putAll(config);
+            if (!empty) {
+                for (Map<String, Object> config : applicableConfigs) {
+                    serverConfiguration.putAll(config);
+                }
             }
         }
 
         // Return its JSON representation
-        return (JSONObject) JSONCoercion.coerceToJSON(serverConfig);
+        return (JSONObject) JSONCoercion.coerceToJSON(serverConfiguration);
     }
 
-    protected boolean looksApplicable(Map<String, Object> value, AJAXRequestData requestData, ServerSession session) throws OXException {
-        if (value == null) {
+    protected boolean looksApplicable(Map<String, Object> possibleConfiguration, AJAXRequestData requestData, ServerSession session) throws OXException {
+        if (possibleConfiguration == null) {
             return false;
         }
-        String host = (String) value.get("host");
-        if (host != null) {
-            if (host.equals(requestData.getHostname()) || "all".equals(host)) {
-                return true;
-            }
-        }
 
-        String hostRegex = (String) value.get("hostRegex");
-        if (hostRegex != null) {
-            try {
-                Pattern pattern = Pattern.compile(hostRegex);
-                if (pattern.matcher(requestData.getHostname()).find()) {
+        // Check "host"
+        {
+            final String host = (String) possibleConfiguration.get("host");
+            if (host != null) {
+                if ("all".equals(host)) {
                     return true;
                 }
-            } catch (final PatternSyntaxException e) {
-                // Ignore. Treat as absent.
+
+                final String hostName = requestData.getHostname();
+                if (host.equals(hostName)) {
+                    return true;
+                }
+
+                // Not applicable according to host check
+                LOGGER.debug("Host '{}' does not apply to {}", host, hostName);
             }
         }
 
-        List<ServerConfigMatcherService> matchers = registry.getMatchers();
-        for (ServerConfigMatcherService matcher : matchers) {
-            if (matcher.looksApplicable(value, requestData, session)) {
-                return true;
+        // Check "hostRegex"
+        {
+            final String keyHostRegex = "hostRegex";
+            final String hostRegex = (String) possibleConfiguration.get(keyHostRegex);
+            if (hostRegex != null) {
+                try {
+                    final Pattern pattern = Pattern.compile(hostRegex);
+
+                    final String hostName = requestData.getHostname();
+                    if (pattern.matcher(hostName).find()) {
+                        return true;
+                    }
+
+                    // Not applicable according to hostRegex check
+                    LOGGER.debug("Host-Regex '{}' does not match {}", hostRegex, hostName);
+                } catch (final PatternSyntaxException e) {
+                    // Ignore. Treat as absent.
+                    LOGGER.debug("Invalid regex pattern for {}: {}", keyHostRegex, hostRegex, e);
+                }
+            }
+        }
+
+        // Check by matchers
+        {
+            final List<ServerConfigMatcherService> matchers = registry.getMatchers();
+            for (final ServerConfigMatcherService matcher : matchers) {
+                if (matcher.looksApplicable(possibleConfiguration, requestData, session)) {
+                    return true;
+                }
             }
         }
 
@@ -218,4 +261,87 @@ public class ConfigAction implements AJAXActionService {
         }
     }
 
+    // ---------------------------------------------------- DEBUG STUFF --------------------------------------------------------------- //
+
+    /**
+     * Output pretty-printed configuration to debug log.
+     *
+     * @param ymlName The name of the YML file
+     * @param configurations The read configurations from YML file
+     */
+    private void debugOut(final String ymlName, final Map<String, Object> configurations) {
+        if (null != configurations) {
+            final Object str = new Object() {
+
+                @Override
+                public String toString() {
+                    return prettyPrintConfigurations(configurations);
+                }
+            };
+            LOGGER.debug("Read configurations from \"{}\": {}", ymlName, str);
+        }
+    }
+
+    String prettyPrintConfigurations(Map<String, Object> configurations) {
+        if (null == configurations) {
+            return "<not-set>";
+        }
+
+        final StringBuilder sb = new StringBuilder(configurations.size() << 4);
+        final String indent = "    ";
+        final String sep = Strings.getLineSeparator();
+        boolean first = true;
+
+        for (final Entry<String, Object> configurationEntry : configurations.entrySet()) {
+            @SuppressWarnings("unchecked")
+            final Map<String, Object> configuration = (Map<String, Object>) configurationEntry.getValue();
+            if (null != configuration) {
+                if (first) {
+                    sb.append(sep);
+                    first = false;
+                }
+
+                prettyPrint(configurationEntry.getKey(), configuration, indent, sep, sb);
+            }
+        }
+
+        if (first) {
+            return "<not-set>";
+        }
+
+        return sb.toString();
+    }
+
+    String prettyPrint(final String configName, Map<String, Object> configuration) {
+        if (null == configuration) {
+            return "<not-set>";
+        }
+
+        final StringBuilder sb = new StringBuilder(configuration.size() << 4);
+        final String indent = "    ";
+        final String sep = Strings.getLineSeparator();
+
+        sb.append(sep);
+        prettyPrint(configName, configuration, indent, sep, sb);
+        return sb.toString();
+    }
+
+    void prettyPrint(final String configName, Map<String, Object> configuration, final String indent, final String sep, final StringBuilder sb) {
+        if (null != configuration) {
+            sb.append(indent).append(configName).append(':').append(sep);
+
+            for (final Entry<String, Object> entry : configuration.entrySet()) {
+                final String key = entry.getKey();
+                final Object value = entry.getValue();
+                sb.append(indent).append(indent).append(key).append(": ");
+                if (value instanceof String) {
+                    sb.append('\'').append(value).append('\'');
+                } else {
+                    sb.append(value);
+                }
+                sb.append(sep);
+            }
+        }
+    }
+
 }
